# Citing Qsymm

We provide Qsymm as free software under a [BSD license](LICENSE).
If you have used Qsymm for work that has lead to a scientific publication, please
mention the fact that you used it explicitly in the text body.

In addition we ask you to cite the [Qsymm paper](https://doi.org/10.1088/1367-2630/aadf67):

    Dániel Varjas, Tómas Ö Rosdahl, and Anton R Akhmerov
    Qsymm: algorithmic symmetry finding and symmetric Hamiltonian generation
    New J. Phys. 20 093026 (2018)
